package com.uc_mobileapps.examples.vaadin.views;

import com.uc_mobileapps.examples.vaadin.dao.CustomerRepository;
import com.uc_mobileapps.examples.vaadin.dao.ProductRepository;
import com.uc_mobileapps.examples.vaadin.entities.Address;
import com.uc_mobileapps.examples.vaadin.entities.Customer;
import com.uc_mobileapps.examples.vaadin.entities.Product;
import com.uc_mobileapps.examples.vaadin.forms.CustomerForm;
import com.uc_mobileapps.examples.vaadin.forms.CustomerGrid;
import com.vaadin.flow.component.dependency.JsModule;
import com.vaadin.flow.component.html.Label;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.data.provider.CallbackDataProvider;
import com.vaadin.flow.data.provider.DataProvider;
import com.vaadin.flow.router.Route;
import com.vaadin.flow.router.RouterLink;
import com.vaadin.flow.spring.annotation.SpringComponent;
import com.vaadin.flow.spring.annotation.UIScope;
import com.vaadin.flow.theme.Theme;
import com.vaadin.flow.theme.lumo.Lumo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;

@UIScope
@SpringComponent
@Route(value = SimpleGrid.PATH)
@Theme(value = Lumo.class, variant = Lumo.DARK)
@JsModule("./styles/shared-styles.html")
public class SimpleGrid extends VerticalLayout {

    public static final String PATH = "customers";
    private final CustomerGrid customerGrid;
    private final CustomerRepository customerRepository;


    @Autowired
    public SimpleGrid(CustomerGrid customerGrid, CustomerRepository customerRepository) {
        this.customerGrid = customerGrid;
        this.customerRepository = customerRepository;

        RouterLink addCustomer = new RouterLink("Add Customer", SimpleEditor.class);

        add(new Label("List of customers"));

        add(customerGrid);
        add(addCustomer);

        addAttachListener(e -> refreshView());

    }

    private void refreshView() {
        CallbackDataProvider<Customer, ?> dataProvider = DataProvider.fromCallbacks(
                query -> customerRepository.findAll(PageRequest.of(query.getOffset() / query.getLimit(),
                                query.getLimit(), Sort.by("lastName"))).stream(),
                query -> Math.toIntExact(customerRepository.count()));

        customerGrid.setDataProvider(dataProvider);
    }
}
